@@ -28,8 +28,6 @@ namespace script {
 // ClassDef = ClassDef(Ident name,                                      TK_CLASS_DEF
 //                     Maybe<Expr> superclass,
 //                     List<Stmt> body)
-// NamedTupleDef = NamedTupleDef(Ident name, List<Ident> fields,
-//                               List<Maybe<Expr>> types)
 //
 // Stmt  = If(Expr cond, List<Stmt> true_body, List<Stmt> false_body)   TK_IF
 //       | For(List<Expr> targets, List<Expr> iters, List<Stmt> body)   TK_FOR
@@ -278,6 +276,7 @@ struct Expr : public TreeView {
       case '+':
       case '-':
       case TK_UNARY_MINUS:
+      case '~':
       case '*':
       case TK_STARRED:
       case '/':
@@ -398,6 +397,9 @@ struct Def : public TreeView {
     auto new_ident = Ident::create(name().range(), std::move(new_name));
     return create(range(), new_ident, decl(), statements());
   }
+  Def withDecl(Decl decl) const {
+    return create(range(), name(), decl, statements());
+  }
   Ident name() const {
     return Ident(subtree(0));
   }
@@ -443,29 +445,6 @@ struct ClassDef : public TreeView {
   }
 };
 
-struct NamedTupleDef : public TreeView {
-  explicit NamedTupleDef(const TreeRef& tree) : TreeView(tree) {
-    tree->match(TK_NAMED_TUPLE_DEF);
-  }
-  Ident name() const {
-    return Ident(subtree(0));
-  }
-  List<Ident> fields() const {
-    return List<Ident>(subtree(1));
-  }
-  List<Maybe<Expr>> type_exprs() const {
-    return List<Maybe<Expr>>(subtree(2));
-  }
-  static NamedTupleDef create(
-      const SourceRange& range,
-      const Ident& name,
-      const List<Ident>& fields,
-      const List<Maybe<Expr>>& type_exprs) {
-    return NamedTupleDef(Compound::create(
-        TK_NAMED_TUPLE_DEF, range, {name, fields, type_exprs}));
-  }
-};
-
 ////////////////////////////////////////////////////////////////////////////////
 // Statements
 ////////////////////////////////////////////////////////////////////////////////
@@ -618,14 +597,20 @@ struct Assign : public Stmt {
   }
   static Assign create(
       const SourceRange& range,
-      const Expr& lhs,
+      const List<Expr>& lhs,
       const Maybe<Expr>& rhs,
       const Maybe<Expr>& type) {
     return Assign(Compound::create(TK_ASSIGN, range, {lhs, rhs, type}));
   }
 
+  List<Expr> lhs_list() const {
+    return List<Expr>(subtree(0));
+  }
+
   Expr lhs() const {
-    return Expr(subtree(0));
+    const auto& li = lhs_list();
+    TORCH_INTERNAL_ASSERT(li.size() == 1);
+    return *li.begin();
   }
 
   Maybe<Expr> rhs() const {
@@ -659,6 +644,10 @@ struct Raise : public Stmt {
   static Raise create(const SourceRange& range, const Maybe<Expr>& expr) {
     return Raise(Compound::create(TK_RAISE, range, {expr}));
   }
+  static Raise create(const SourceRange& range) {
+    return Raise(
+        Compound::create(TK_RAISE, range, {Maybe<Expr>::create(range)}));
+  }
 };
 
 struct Assert : public Stmt {
@@ -784,6 +773,7 @@ struct UnaryOp : public Expr {
   explicit UnaryOp(const TreeRef& tree) : Expr(tree) {
     switch (tree->kind()) {
       case TK_UNARY_MINUS:
+      case '~':
       case TK_NOT:
         if (tree->trees().size() != 1)
           throw ErrorReport(tree)
