@@ -8,6 +8,7 @@ future.
 from .adadelta import Adadelta  # noqa: F401
 from .adagrad import Adagrad  # noqa: F401
 from .adam import Adam  # noqa: F401
+from .adamw import AdamW  # noqa: F401
 from .sparse_adam import SparseAdam  # noqa: F401
 from .adamax import Adamax  # noqa: F401
 from .asgd import ASGD  # noqa: F401
@@ -21,6 +22,7 @@ from . import lr_scheduler  # noqa: F401
 del adadelta
 del adagrad
 del adam
+del adamw
 del sparse_adam
 del adamax
 del asgd
